@@ -1,27 +1,12 @@
 use ::syntax::ptr::P;
-use ::syntax::ast::{MetaItem, MetaItem_, Item_, Ident, StructField, VariantData, Lit_, Expr, Stmt};
+use ::syntax::ast::{MetaItem, MetaItem_, Item_, Ident, StructField, VariantData, Expr, Stmt};
 use ::syntax::codemap::{Span, Spanned};
 use ::syntax::ext::base::{Annotatable, ExtCtxt};
 use ::syntax::ext::build::AstBuilder;
 
 use syntax::attr::AttrMetaMethods;
 
-fn get_meta_item_value(meta_item: &MetaItem, name: &str) -> Option<String> {
-    match meta_item {
-        &Spanned { node: MetaItem_::MetaList(_, ref items), span: _ } => {
-            for ref item in items {
-                if item.name() == name {
-                    match item.value_str() {
-                        Some(value) => return Some(value.to_string()),
-                        None => (),
-                    }
-                }
-            }
-            None
-        }
-        _ => None
-    }
-}
+use ::util::{get_meta_item_value};
 
 pub fn transcoder_decorator(
     cx: &mut ExtCtxt,
